@@ -26,7 +26,7 @@
 typedef size_t gsize;
 typedef ptrdiff_t gssize;
 
-#define G_GSIZE_FORMAT   "%u"
+#define G_GSIZE_FORMAT   "u"
 
 #if defined (HOST_WATCHOS)
 #undef G_BREAKPOINT
